@@ -15,23 +15,21 @@ import network
 import _thread
 import time
 
-# pip installed packages
-# import picoweb
-# https://github.com/pfalcon/picoweb/blob/b74428ebdde97ed1795338c13a3bdf05d71366a0/picoweb/
-from uModbus.serial import Serial as ModbusRTUMaster
-from uModbus.tcp import TCP as ModbusTCPMaster
-# https://github.com/brainelectronics/micropython-modbus/
-from primitives.message import Message
-# https://github.com/peterhinch/micropython-async/blob/a87bda1b716090da27fd288cc8b19b20525ea20c/v3/primitives/
-
 # custom packages
-from helpers.generic_helper import GenericHelper
-from helpers.path_helper import PathHelper
-from modbus import ModbusRTU
-from modbus import ModbusTCP
+# pip installed packages
+# https://github.com/brainelectronics/micropython-modules
+from .generic_helper import GenericHelper
+from .message import Message
+from .path_helper import PathHelper
+# typing not natively supported on MicroPython
+from .typing import Dict, Tuple, Union
 
-# not natively supported on micropython, see lib/typing.py
-from typing import Dict, Tuple, Union
+# https://github.com/brainelectronics/micropython-modbus/
+# upip.install('micropython-modbus')
+from umodbus.serial import Serial as ModbusRTUMaster
+from umodbus.tcp import TCP as ModbusTCPMaster
+from umodbus.modbus import ModbusRTU
+from umodbus.modbus import ModbusTCP
 
 
 class ModbusBridgeError(Exception):
@@ -581,8 +579,8 @@ class ModbusBridge(object):
             self.logger.info('Created TCP client to serve on {}:{}'.
                              format(local_ip, port))
 
-            _client.setup_registers(registers=self.register_definitions,
-                                    use_default_vals=True)
+        _client.setup_registers(registers=self.register_definitions,
+                                use_default_vals=True)
 
         self.host = _host
         self.client = _client
